Decomposition
=============

.. currentmodule:: pykeen.nn.message_passing

.. autoclass:: Decomposition
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Decomposition.forward
      ~Decomposition.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: reset_parameters
